@@ -1,4 +1,5 @@
 from nats.aio.client import Client as NATS
+from nats.aio.errors import ErrConnectionClosed, ErrTimeout, ErrNoServers
 import json
 import os
 import asyncio
@@ -28,7 +29,7 @@ class NeoNatsClient(NATS):
             password=self.npq_pass,
             io_loop=loop,
         )
-        self.logger.info(f"Connected to nats://{self.npq_host}:{self.npq_port}")
+        self.logger.info(f"Connected to {nats_url}")
 
     async def process(self, queue, processor):
         async def process_handler(msg):
